import React from 'react';
import {  Button, Input, Select, Spin, Table, Switch, message, DatePicker } from 'antd';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './techDemand.less';
import TechDemandDesc from './authDesc.jsx';
import {industry} from '@/dataDic.js';
import { getIndustry } from '@/tools.js';

const DemandList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/demand/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                identifyName: this.state.nameSearch,
                industry:this.state.demandTypeSearch,
                authType: this.state.statusSearch
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            status: thisdata.status,
                            name: thisdata.name,
                            demandType: thisdata.demandType,
                            auditStatus: thisdata.auditStatus,
                            isHot: thisdata.isHot,
                            isUrgent: thisdata.isUrgent,
                            employerName:thisdata.employerName,
                            createTime:thisdata.createTime?(new Date(thisdata.createTime)).toLocaleString():'',
                            releaseDate:thisdata.releaseDate?(new Date(thisdata.releaseDate)).toLocaleString():''
                        });
                    };
                }
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                if(data.data&&data.data.list&&!data.data.list.length){
					this.state.pagination.current=0
					this.state.pagination.total=0
				}
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '姓名',
                    dataIndex: 'identifyName',
                    key: 'identifyName',
                    render:text=>{
                        return text&&text.length>16?text.substr(0,16)+'...':text
                    }
                },
                 {
                    title: '手机号码',
                    dataIndex: 'mobile',
                    key: 'mobile',
                },
                 {
                    title: '行业',
                    dataIndex: 'industry',
                    key: 'industry',
                    render: (text) => { return getIndustry(text); }
                },
                
                {
                    title: '认证类型',
                    dataIndex: 'authType',
                    key: 'authType',
                    render: text => { return text=='0'?'专家认证':text=='1'?'顾问认证':'未认证' }
                },
                {
                    title: '认证审核',
                    dataIndex: 'caozuo',
                    key: 'caozuo',
                    render:(text,recard) => {
                        return  <div className="btnRight">
                                   <Button type="primary" onClick={(e)=>{e.stopPropagation();this.tableRowClick(recard)}}>审核</Button>
                                </div>
                    }
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    componentWillMount() {
        let theArr = [];
        industry.map(function (item) {
            theArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        this.state.demandTypeOption = theArr;
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true,
            examineState:true
        });
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            if(this.state.pagination.total%10==1){
                this.loadData((this.state.page)-1);
            }else{
                this.loadData(this.state.page);
            }
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.nameSearch = '';
        this.state.demandTypeSearch = undefined;
        this.state.auditStatus = undefined;
        this.state.statusSearch = undefined;
        this.state.employerNameSearch='';
        this.state.releaseDate = [];
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { RangePicker } = DatePicker;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>专家顾问认证审核</span>
                </div>
                <div className="user-search">
                    <Input placeholder="姓名"
                        value={this.state.nameSearch}
                        onChange={(e) => { this.setState({ nameSearch: e.target.value }); }} />
                    <Select placeholder="行业"
                        style={{ width: 120 }}
                        value={this.state.demandTypeSearch}
                        onChange={(e) => { this.setState({ demandTypeSearch: e }) }}>
                        {this.state.demandTypeOption}
                    </Select>
                    <Select placeholder="认证类型" style={{ width: 160 }}
                        value={this.state.statusSearch}
                        onChange={(e) => { this.setState({ statusSearch: e }) }}>
                        <Select.Option value="0" >专家认证</Select.Option>
                        <Select.Option value="1" >顾问认证</Select.Option>
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                             />
                    </Spin>
                </div>
                <TechDemandDesc
                    data={this.state.RowData}
                    demandTypeOption={this.state.demandTypeOption}
                    examineState={this.state.examineState}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div >
        );
    }
});

export default DemandList;