import React from 'react';
import {Button, Input, Select, Spin, Table, Switch, message, DatePicker } from 'antd';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './techDemand.less';
import TechDemandDesc from './demandDesc.jsx';
import { demandTypeList } from '@/dataDic.js';
import { getDemandType,getReleaseStateList } from '@/tools.js';

const DemandList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            page:pageNo,
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/demand/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                employerName: this.state.employerNameSearch,//客户名称
                name: this.state.nameSearch,
                auditStatus:this.state.auditStatusSearch,
                demandType: this.state.demandTypeSearch ? Number(this.state.demandTypeSearch) : undefined,
                status: this.state.statusSearch ? Number(this.state.statusSearch) : undefined,
                startDate: this.state.releaseDate[0],
                endDate: this.state.releaseDate[1],
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            status: thisdata.status,
                            name: thisdata.name,
                            demandType: thisdata.demandType,
                            auditStatus: thisdata.auditStatus,
                            isHot: thisdata.isHot,
                            isUrgent: thisdata.isUrgent,
                            employerName:thisdata.employerName,
                            createTime:thisdata.createTime?(new Date(thisdata.createTime)).toLocaleString():'',
                            releaseDate:thisdata.releaseDate?(new Date(thisdata.releaseDate)).toLocaleString():''
                        });
                    };
                }
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                if(data.data&&data.data.list&&!data.data.list.length){
					this.state.pagination.current=0
					this.state.pagination.total=0
				}
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '需求名称',
                    dataIndex: 'name',
                    key: 'name',
                },  {
                    title: '需求类型',
                    dataIndex: 'demandType',
                    key: 'demandType',
                    render: (text) => { return getDemandType(text); }
                },
                {
                    title: '是否热门',
                    dataIndex: 'isHot',
                    key: 'isHot',
                    render: text => { return text?'热门':'非热门'; }
                },
                {
                    title: '是否加急',
                    dataIndex: 'isUrgent',
                    key: 'isUrgent',
                    render: text => { return text?'加急':'未加急' }
                },
                {
                    title: '客户名称',
                    dataIndex: 'employerName',
                    key: 'employerName'
                },
                {
                    title: '发布状态',
                    dataIndex: 'auditStatus',
                    key: 'auditStatus',
                    render: text => { return getReleaseStateList(text) }
                },
                {
                    title: '需求状态',
                    dataIndex: 'status',
                    key: 'status',
                    render: text => {
                        return  <div>
                                    {text=='0'&&<span>进行中</span>}
                                    {text=='1'&&<span>未解决</span>}
                                    {text=='2'&&<span>已解决</span>}
                                </div>

                     }
                },
                {
                    title: '创建时间',
                    dataIndex: 'createTime',
                    key: 'createTime',
                },
                {
                    title: '发布时间',
                    dataIndex: 'releaseDate',
                    key: 'releaseDate'
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    componentWillMount() {
        let theArr = [];
        demandTypeList.map(function (item) {
            theArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        this.state.demandTypeOption = theArr;
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true,
            examineState:false
        });
    },
    delectRow(recard) {
        this.setState({
            loading:true
        })
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/demand/delete",
            data: {
                ids: recard.id
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('删除成功！');
                this.setState({
                    loading: false,
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData(this.state.page);
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.nameSearch = '';
        this.state.demandTypeSearch = undefined;
        this.state.auditStatusSearch = undefined;
        this.state.statusSearch = undefined;
        this.state.employerNameSearch='';
        this.state.releaseDate = [];
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { RangePicker } = DatePicker;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>科技需求库</span>
                </div>
                <div className="user-search">
                    <Input placeholder="需求名称"
                        value={this.state.nameSearch}
                        onChange={(e) => { this.setState({ nameSearch: e.target.value }); }} />
                    <Select placeholder="选择需求类型"
                        style={{ width: 120 }}
                        value={this.state.demandTypeSearch}
                        onChange={(e) => { this.setState({ demandTypeSearch: e }) }}>
                        {this.state.demandTypeOption}
                    </Select>
                    <Select placeholder="发布状态" style={{ width: 120 }}
                        value={this.state.auditStatusSearch}
                        onChange={(e) => { this.setState({ auditStatusSearch: e }) }}>
                        <Select.Option value="0" >草稿</Select.Option>
                        <Select.Option value="1" >发布审核</Select.Option>
                        <Select.Option value="2" >已发布</Select.Option>
                        <Select.Option value="3" >发布失败</Select.Option>
                        <Select.Option value="4" >已撤销</Select.Option>
                    </Select>
                    <Select placeholder="需求状态" style={{ width: 160 }}
                        value={this.state.statusSearch}
                        onChange={(e) => { this.setState({ statusSearch: e }) }}>
                        <Select.Option value="0" >进行中</Select.Option>
                        <Select.Option value="1" >未解决</Select.Option>
                        <Select.Option value="2" >已解决</Select.Option>
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                    <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                    <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                        <Input style={{width:140,marginRight:10}} value={this.state.employerNameSearch} onChange={(e)=>{this.setState({employerNameSearch:e.target.value})}} placeholder="客户名称"/>
                        <span>发布时间 :</span>
                        <RangePicker
                            value={[this.state.releaseDate[0] ? moment(this.state.releaseDate[0]) : null,
                            this.state.releaseDate[1] ? moment(this.state.releaseDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ releaseDate: dataString }); }} />
                    </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <TechDemandDesc
                    data={this.state.RowData}
                    examineState={this.state.examineState}
                    demandTypeOption={this.state.demandTypeOption}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div>
        );
    }
});

export default DemandList;